# `qiskit-transpiler

The Rust-based transpiler functionality. It contains transpilation specific data models and transpiler
functions for individual transpiler passes.

## src/target module

This module defines the target model in Qiskit used for representing
a compilation Target.

## src/passes module

This module contains the transpiler pass implementations.
